Range-v3: ranges::v3::concepts::Callable Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Types | Public Member Functions | List of all members
ranges::v3::concepts::Callable Struct Reference

## Public Types
template<typename Fun , typename... Args>
using | result_t = Function::result_t< function_type< Fun >, Args... >

## Public Member Functions
template<typename Fun , typename... Args>
auto | requires_ (Fun &&, Args &&...) -> decltype( concepts::valid_expr( concepts::model_of< Function, function_type< Fun >, Args... >() ))